      SUBROUTINE TYPE55(TIME,XIN,OUT,T,DTDT,PAR,INFO,ICNTRL,*)

C*******************************************************************************
C PERIODIC SUMMARY ROUTINE - WRITTEN BY JEFF THORNTON FOR TRNSYS                                    
C VERSION 14.0                                                   
C                                                                
C THIS ROUTINE TAKES UP TO TEN INPUTS AND CALCULATES THE MEAN,   
C STANDARD DEVIATION, MINIMUM, MAXIMUM AND VARIANCE OF EACH      
C INPUT. THIS ROUTINE WILL ALSO CALCULATE THE INTEGRAL OF EACH   
C INPUT WITH RESPECT TO TIME - OR THE SUM OF THE INPUT OVER THE  
C TIME RANGE.                                                    
C
C Revision History
C ----------------
C
C 1993/07/10 - JWT - Multiple Year Fix
C 2002/05/21 - JWT - Fixed an error when the start summary period occurred after 
C                    the simulation start time
C 2002/10/11 - JWT - Fix to get proper daily value at midnight when time step is 
C                    less than 1
C                  - Cleaning (replaced 0.0001 by DT/2, etc.) 
C
C*******************************************************************************

C*******************************************************************************
C*  PARAMETERS: IN GROUPS OF 7 FOR EACH INPUT                                                    
C*      1) I -      INPUT FOR WHICH NEXT SIX PARAMETERS APPLY    
C*                  IF I<0: INPUT I SHOULD BE INTEGRATED WITH    
C*                  RESPECT TO TIME, IF I>0: I SHOULD BE SUMMED  
C*                  OVER THE TIME RANGE.                         
C*      2) TON -    STARTING TIME OF DAY FOR PERIODIC SUMMARY    
C*      3) LENGTH - LENGTH OF TIME FOR PERIODIC SUMMARY          
C*                  IF LENGTH < 0, STOP AT END OF MONTH          
C*      4) XREPEAT - NUMBER OF HOURS AT WHICH TO REPEAT PERIODIC  
C*                  SUMMARY. IF < 0, REPEAT EVERY MONTH          
C*      5) RESET  - NUMBER OF HOURS AFTER WHICH PERIODIC SUMMARY 
C*                  SHOULD BE PRINTED AND RESET                  
C*      6) START  - STARTING HOUR OF YEAR FOR PERIODIC SUMMARY   
C*      7) XSTOP   - STOPPING HOUR OF YEAR FOR PERIODIC  SUMMARY  
C*******************************************************************************

      INCLUDE '../include/param.inc'
      DOUBLE PRECISION XIN,OUT
      INTEGER*4 INFO
      DIMENSION XIN(10),PAR(70),OUT(100),INFO(15)
      DIMENSION TON(10),LENGTH(10),START(10),XSTOP(10),RESET(10)
      DIMENSION IQUANT(10),NEXT(10),LAST(10),NUM(10),NEWVAL(10)
      DIMENSION XSUM(10),MEAN(10),STDEV(10),VMIN(10),VMAX(10)
      DIMENSION VAL(10),MONTH(0:121),KEEP(10),SSQ(10),TMIN(10),TMAX(10)
      DIMENSION VAR(10),MONTH1(10),MONTH2(10),MONTH3(10),NTGRAL(10)
      DIMENSION SUMSQ(10),M1(10),M2(10),M3(10),XREPEAT(10)

      REAL NTGRAL,NEXT,LAST,NEWVAL,MONTH,MEAN,VMIN,VMAX,TMIN,TMAX
      REAL TON,LENGTH,START,XSTOP,RESET,XREPEAT,XSUM,STDEV,VAL,SSQ
      REAL SUMSQ,M1,M2,M3
      INTEGER IQUANT,I,KEEP,NUM
      LOGICAL MONTH1,MONTH2,MONTH3,CONT
      CHARACTER*3 YCHECK(10),OCHECK(100),TRUTYP,OUTYPE

      COMMON /SIM/ TIME0,TIMEF,DT,IWARN
      COMMON /LUNITS/ LUR,LUW,IFORM,LUK
      COMMON /STORE/NSTORE,IAV,S(NUMSTR)

      DATA MONTH/0.,744.,1416.,2160.,2880.,3624.,4344.,5088.,5832.,
     .             6552.,7296.,8016.,8760.,9504.,10176.,10920.,11640.,
     .        12384.,13104.,13848.,14592.,15312.,16056.,16776.,17520.,
     .        18264.,18936.,19680.,20400.,21144.,21864.,22608.,23352.,
     .        24072.,24816.,25536.,26280.,27024.,27696.,28440.,29160.,
     .        29904.,30624.,31368.,32112.,32832.,33576.,34296.,35040.,
     .        35784.,36456.,37200.,37920.,38664.,39384.,40128.,40872.,
     .        41592.,42336.,43056.,43800.,44544.,45216.,45960.,46680.,
     .        47424.,48144.,48888.,49632.,50352.,51096.,51816.,52560.,
     .        53304.,53976.,54720.,55440.,56184.,56904.,57648.,58392.,
     .        59112.,59856.,60576.,61320.,62064.,62736.,63480.,64200.,
     .        64944.,65664.,66408.,67152.,67872.,68616.,69336.,70080.,
     .        70824.,71496.,72240.,72960.,73704.,74424.,75168.,75912.,
     .        76632.,77376.,78096.,78840.,79584.,80256.,81000.,81720.,
     .        82464.,83184.,83928.,84672.,85392.,86136.,86856.,87600.,
     .        88344./


C    DEFINITIONS
C    *****************************************************************
C    IQUANT(I)  - TELLS ROUTINE WHETHER INPUT(I) IS A RATE OR NOT
C    KEEP(I)    - POINTER INTO MONTH ARRAY
C    LAST(I)    - TIME FOR END OF SUMMARY OF INPUT(I) = F(LENGTH,REPEAT)
C    MEAN(I)    - THE AVERAGE VALUE OF INPUT I
C    MONTH      - ARRAY CONTAINING ENDING HOURS OF MONTHS
C    MONTH1,2,3 - LOGICAL VARIABLES INDICATING MONTHLY
C    NEWVAL(I)  - TIME FOR NEXT RESET
C    NEXT(I)    - TIME TO START EVALUATING INPUT (I) = F(TON,REPEAT)
C    NTGRAL(I)  - INTEGRAL OF XIN(I) WITH RESPECT TO TIME
C    NUM(I)     - NUMBER OF VALUES OF INPUT I
C    XREPEAT(I)  - REPEAT TIME FOR SUMMARY OF INPUT(I)
C    RESET(I)   - RESET TIME FOR SUMMARY OF INPUT(I)
C    SSQ(I)     - SUM OF SQUARES OF VAL(I)-MEAN(I)
C    START(I)   - START TIME FOR SUMMARY OF INPUT(I)
C    STDEV(I)   - STANDARD DEVIATION OF SAMPLE INPUT I
C    XSTOP(I)    - STOP TIME FOR SUMMARY OF INPUT(I)
C    XSUM(I)     - SUM OF INPUTS I OVER TIME RANGE
C    SUMSQ(I)   - SUM OF (INPUT I)^2 OVER TIME RANGE
C    TMAX(I)    - TIME AT WHICH MAXIMUM VALUE OF INPUT I OCCURRED
C    TMIN(I)    - TIME AT WHICH MINIMUM VALUE OF INPUT I OCCURRED
C    TON(I)     - TIME OF DAY FOR START OF PERIODIC SUMMARY OF INPUT(I)
C    LENGTH(I)  - LENGTH OF TIME FOR PERIODIC SUMMARY OF INPUT(I)
C    VAL(I)     - INPUT I
C    VAR(I)     - VARIANCE OF INPUT I
C    VMAX(I)    - MAXIMUM VALUE OF INPUT I
C    VMIN(I)    - MINIMUM VALUE OF INPUTS I
C    *****************************************************************

C     FINAL CALL OF SIMULATION (INFO(8)=-1) SIMPLY RETURN SO SUMS ARE NOT ALTERED
      IF(INFO(8).EQ.-1) RETURN 1

C    FIRST CALL OF SIMULATION
      IF(INFO(7).LT.0) THEN

C       SET THE S ARRAY FOR MULTIPLE UNITS
         INFO(10)=250

C       SET CORRECT # OF OUTPUTS AND TELL TRNSYS TO CALL THIS UNIT ONLY
C       AT THE END OF EACH TIMESTEP, BUT BEFORE PRINTERS
         INFO(6)=100
         INFO(9)=3

C       SET CORRECT # OF PARAMETERS, # OF INPUTS, AND # DERIVATIVES
         NI=INFO(3)
         NP=INFO(3)*7
         ND=0

C       CALL TYPECK TO CHECK FOR PROPER # OF PARS, INPUTS, OUTS
         CALL TYPECK(1,INFO,NI,NP,ND)

C       SET THE S POINTER
         JJ=INFO(10)

C       CHECK FOR MAXIMUM # OF 10 INPUTS
         IF(NI.GT.10) THEN
            CALL TYPECK(3,INFO,NI,NP,ND)
         ENDIF

C       GET THE PARAMETERS FROM THE DECK
         DO 5, I=1,NI
            J=INT((I-1)*7)
            IQUANT(I)=INT(PAR(1+J)+0.01)
            TON(I)=PAR(2+J)
            LENGTH(I)=PAR(3+J)
            XREPEAT(I)=PAR(4+J)
            RESET(I)=PAR(5+J)
            START(I)=PAR(6+J)
            XSTOP(I)=PAR(7+J)
 5       CONTINUE

C       CHECK FOR CORRECT RANGE IN PARAMETER LIST
         DO 10, I=1,NI

C          CHECK TO SEE IF STOP TIME SHOULD BE THE END OF THE MONTH
            IF(LENGTH(I).LT.0) THEN
                MONTH1(I)=.TRUE.
                M1(I)=1
             ELSE
                MONTH1(I)=.FALSE.
                M1(I)=0
             ENDIF

C          CHECK TO SEE IF REPEAT TIME IS MONTHLY
            IF(XREPEAT(I).LT.0) THEN
               MONTH2(I)=.TRUE.
               M2(I)=1
            ELSE IF (MONTH1(I)) THEN
               MONTH2(I)=.TRUE.
               M2(I)=1
            ELSE
               MONTH2(I)=.FALSE.
               M2(I)=0
            ENDIF

C          CHECK TO SEE IF RESET TIME IS MONTHLY
            IF(RESET(I).LT.0) THEN
               MONTH3(I)=.TRUE.
               M3(I)=1
            ELSE
               MONTH3(I)=.FALSE.
               M3(I)=0
            ENDIF

C          LOOK FOR BAD PARAMETERS
            IF(START(I).GE.XSTOP(I)) CALL TYPECK(4,INFO,NI,NP,ND)
            IF(TON(I).GE.XSTOP(I)) CALL TYPECK(4,INFO,NI,NP,ND)

C          DETERMINE THE MONTH CONTAINING TIME0
            IF(MONTH1(I).OR.MONTH2(I).OR.MONTH3(I)) THEN
               DO 100 II=1,121
                  IF (MONTH(II).GT.TIME0) THEN
                     KEEP(I)=II
                     GO TO 200
                  ENDIF
 100           CONTINUE
            ENDIF
 200        CONTINUE

C          SET INITIAL NEXT VALUES FOR EACH INPUT
            IF(TON(I).LT.0.) THEN
               NEXT(I)=0.
              IF (MONTH1(I)) THEN
                 LAST(I)=MONTH(KEEP(I))
              ELSE
                 LAST(I)=NEXT(I)+LENGTH(I)
              ENDIF
            ELSE IF(TON(I).LT.(TIME0-0.0001)) THEN
              NEXT(I)=TON(I)+(TIME0-MOD(TIME0,24.))

              IF (MONTH1(I)) THEN
                 LAST(I)=MONTH(KEEP(I))
              ELSE
                 LAST(I)=NEXT(I)+LENGTH(I)
              ENDIF

              IF(LAST(I).LT.(TIME0-0.0001)) THEN
			   NEXT(I)=NEXT(I)+24.
                 IF (MONTH1(I)) THEN
                    LAST(I)=MONTH(KEEP(I))
                 ELSE
                    LAST(I)=NEXT(I)+LENGTH(I)
                 ENDIF
	         ENDIF
            ELSE
              NEXT(I)=TON(I)
              IF (MONTH1(I)) THEN
                 LAST(I)=MONTH(KEEP(I))
              ELSE
                 LAST(I)=NEXT(I)+LENGTH(I)
              ENDIF
            ENDIF

C         SET THE INITIAL VALUES OF LAST

C          INITIALIZE VARIABLE ARRAYS
            XSUM(I)=0.
            SUMSQ(I)=0.
            NTGRAL(I)=0.
            MEAN(I)=0.
            STDEV(I)=0.
            VAR(I)=0.
            VMIN(I)=1.0E12
            VMAX(I)=-1.0E12
            TMIN(I)=TIME0
            TMAX(I)=TIME0
            NUM(I)=0.
            SSQ(I)=0.

C          SET THE INITIAL VALUE OF THE RESET TIME
            IF(MONTH3(I)) THEN
               RESET(I)=MONTH(KEEP(I))
               NEWVAL(I)=RESET(I)
            ELSE
               NEWVAL(I)=TON(I)+RESET(I)
            ENDIF

C          SET THE INITIAL S VARIABLES
            S(JJ+I)=REAL(IQUANT(I))
            S(JJ+I+10)=LENGTH(I)
            S(JJ+I+20)=XREPEAT(I)
            S(JJ+I+30)=RESET(I)
            S(JJ+I+40)=START(I)
            S(JJ+I+50)=XSTOP(I)
            S(JJ+I+60)=M1(I)
            S(JJ+I+70)=M2(I)
            S(JJ+I+80)=M3(I)
            S(JJ+I+90)=NEXT(I)
            S(JJ+I+100)=LAST(I)
            S(JJ+I+110)=REAL(NUM(I))
            S(JJ+I+120)=XSUM(I)
            S(JJ+I+130)=SUMSQ(I)
            S(JJ+I+140)=NTGRAL(I)
            S(JJ+I+150)=VMAX(I)
            S(JJ+I+160)=TMAX(I)
            S(JJ+I+170)=VMIN(I)
            S(JJ+I+180)=TMIN(I)
            S(JJ+I+190)=MEAN(I)
            S(JJ+I+200)=STDEV(I)
            S(JJ+I+210)=VAR(I)
            S(JJ+I+220)=SSQ(I)
            S(JJ+I+230)=REAL(KEEP(I))
            S(JJ+I+240)=NEWVAL(I)

 10      CONTINUE
         RETURN 1
      ENDIF

C    CALL THE I/O CHECKING ROUTINE IF ITS TIME
      IF(INFO(8).EQ.2) THEN
C       DETERMINE THE INPUT VARIABLE TYPE AND CALL THE I/O CHECKING ROUTINE
C       AT THE SECOND ITERATION IN ORDER TO GET THE INPUT TYPES
         IU=INFO(1)
         DO 2 J=1,INFO(3)
            CALL EQUATER(IU,J,'NAV',TRUTYP,IU2,IO2,OUTYPE,X1,A1,X2,A2,
     1               ICK1,ICK2,ICK3)
            YCHECK(J)=TRUTYP
            OCHECK(1+10*(J-1))='NAV'
            OCHECK(2+10*(J-1))=YCHECK(J)
            OCHECK(3+10*(J-1))=YCHECK(J)
            OCHECK(4+10*(J-1))=YCHECK(J)
            OCHECK(5+10*(J-1))=YCHECK(J)
            OCHECK(6+10*(J-1))=YCHECK(J)
            OCHECK(7+10*(J-1))=YCHECK(J)
            OCHECK(8+10*(J-1))='TD1'
            OCHECK(9+10*(J-1))=YCHECK(J)
            OCHECK(10*J-1)='TD1'
 2       CONTINUE

         CALL RCHECK(INFO,YCHECK,OCHECK)
      ENDIF
      JJ=INFO(10)

C    END OF FIRST CALL BOOKKEEPING - NOW DO THE SUMMARY
      DO 50 I=1,INFO(3)

      IQUANT(I)=INT(S(JJ+I)+0.1)
      LENGTH(I)=S(JJ+I+10)
      XREPEAT(I)=S(JJ+I+20)
      RESET(I) =S(JJ+I+30)
      START(I) =S(JJ+I+40)
      XSTOP(I)  =S(JJ+I+50)

      M1(I)=S(JJ+I+60)
      IF(M1(I).GT.0.5) THEN
         MONTH1(I)=.TRUE.
      ELSE
         MONTH1(I)=.FALSE.
      ENDIF

      M2(I)=S(JJ+I+70)
      IF(M2(I).GT.0.5) THEN
         MONTH2(I)=.TRUE.
      ELSE
         MONTH2(I)=.FALSE.
      ENDIF

      M3(I)=S(JJ+I+80)
      IF(M3(I).GT.0.5) THEN
         MONTH3(I)=.TRUE.
      ELSE
         MONTH3(I)=.FALSE.
      ENDIF

      NEXT(I)  =S(JJ+I+90)
      LAST(I)  =S(JJ+I+100)
      NUM(I)   =INT(S(JJ+I+110)+0.1)
      XSUM(I)   =S(JJ+I+120)
      SUMSQ(I) =S(JJ+I+130)
      NTGRAL(I)=S(JJ+I+140)
      VMAX(I)  =S(JJ+I+150)
      TMAX(I)  =S(JJ+I+160)
      VMIN(I)  =S(JJ+I+170)
      TMIN(I)  =S(JJ+I+180)
      MEAN(I)  =S(JJ+I+190)
      STDEV(I) =S(JJ+I+200)
      VAR(I)   =S(JJ+I+210)
      SSQ(I)   =S(JJ+I+220)
      KEEP(I)  =INT(S(JJ+I+230)+0.1)
      NEWVAL(I)=S(JJ+I+240)

C    SET THE RESET AND REPEAT TIMES
      IF(MONTH3(I)) RESET(I)=MONTH(KEEP(I))
      IF(MONTH2(I)) XREPEAT(I)=MONTH(KEEP(I))

C    GET THE INPUTS AND ASSIGN THEM TO THE VAL ARRAY
      VAL(I)=XIN(I)

C    CHECK TO SEE WHETHER CURRENT TIME FALLS BETWEEN TIME RANGE FOR
C    SUMMARY MANIPULATION AND START-STOP TIMES IF IT DOES, ALLOW SUMMARY
C    MANIPULATION

C     TIME RANGE SHOULD INCLUDE LAST TIME
      IF((TIME.GE.(NEXT(I)+DT/2.)).AND.(TIME.LE.(LAST(I)+DT/2.))
     1   .AND.(TIME.GE.(START(I)-DT/2.)).AND.(TIME.LE.(XSTOP(I)
     1   +DT/2.)))  THEN
         CONT=.TRUE.
      ELSE
         CONT=.FALSE.
      ENDIF

C    RESET THE SUMMARY VARIABLES FOR NEXT RESET PERIOD
      IF(((TIME.GE.(NEWVAL(I)+DT/2.)).AND.(TIME.LE.(NEWVAL(I)
     1   +3.*DT/2.)))) THEN
         NTGRAL(I)=0.
         MEAN(I)=0.
         STDEV(I)=0.
         VAR(I)=0.
         SSQ(I)=0.
         VMIN(I)=1.0E12
         VMAX(I)=-1.0E12
         NUM(I)=0.
         XSUM(I)=0.
         SUMSQ(I)=0.
         TMIN(I)=TIME
         TMAX(I)=TIME
      ENDIF


C    START THE SUMMARY FOR INPUT I
      IF(CONT) THEN

C       UPDATE COUNT
         NUM(I)=NUM(I)+1

C       CALCULATE SUM AND SUM SQUARED OF I
         XSUM(I)=XSUM(I)+VAL(I)
         SUMSQ(I)=SUMSQ(I)+(VAL(I)**2.)

C       CALCULATE INTEGRALS
         NTGRAL(I)=NTGRAL(I)+VAL(I)*DT

C       CHECK TO SEE IF INPUT IS A LOCAL MINIMUM OR MAXIMUM
         IF(VAL(I).GT.VMAX(I)) THEN
            VMAX(I)=VAL(I)
            TMAX(I)=TIME
         ENDIF

         IF(VAL(I).LT.VMIN(I)) THEN
            VMIN(I)=VAL(I)
            TMIN(I)=TIME
         ENDIF

C       CALCULATE MEAN,STANDARD DEVIATION, VARIANCE AND SUM OF SQUARES
         MEAN(I)=XSUM(I)/REAL(NUM(I))
         IF(NUM(I).EQ.1) THEN
            STDEV(I)=0.
            VAR(I)=0.
            SSQ(I)=0.
         ELSE
            DUMM=((SUMSQ(I)-(XSUM(I)**2.)/REAL(NUM(I)))/REAL(NUM
     .                          (I)-1))
            IF(DUMM.GT.0.0) THEN
               STDEV(I)=DUMM**0.5
            ELSE
               STDEV(I)=0
            ENDIF
            VAR(I)=STDEV(I)**2.
            SSQ(I)=VAR(I)*REAL(NUM(I)-1)
         ENDIF

C       SET THE NEW RANGE VALUES FOR TIME SUMMARY IF THE NEXT TIME-
C       STEP IS OUTSIDE OF THE CURRENT RANGE
         IF(MONTH1(I)) THEN
            IF((TIME+DT).GT.(LAST(I)+DT/2.)) THEN
               NEXT(I)=NEXT(I)+MONTH(KEEP(I))-MONTH(KEEP(I)-1)
               LAST(I)=MONTH(KEEP(I)+1)
            ENDIF
         ELSE
            IF((TIME+DT).GT.(LAST(I)+DT/2.)) THEN
               IF(MONTH2(I)) THEN
                  NEXT(I)=NEXT(I)+MONTH(KEEP(I))-MONTH(KEEP(I)-1)
                  LAST(I)=NEXT(I)+LENGTH(I)
               ELSE
                  NEXT(I)=NEXT(I)+XREPEAT(I)
                  LAST(I)=NEXT(I)+LENGTH(I)
               ENDIF
            ENDIF
         ENDIF

      ELSE
	   IF(MONTH1(I)) THEN
            IF((TIME+DT).GT.(LAST(I)+DT/2.)) THEN
               NEXT(I)=NEXT(I)+MONTH(KEEP(I))-MONTH(KEEP(I)-1)
               LAST(I)=MONTH(KEEP(I)+1)
            ENDIF
         ELSE
            IF((TIME+DT).GE.(LAST(I)+DT/2.)) THEN
               IF(MONTH2(I)) THEN
                  NEXT(I)=NEXT(I)+MONTH(KEEP(I))-MONTH(KEEP(I)-1)
                  LAST(I)=NEXT(I)+LENGTH(I)
               ELSE
                  NEXT(I)=NEXT(I)+XREPEAT(I)
                  LAST(I)=NEXT(I)+LENGTH(I)
               ENDIF
            ENDIF
         ENDIF
      ENDIF

C    SET THE OUTPUTS
      J=INT((I-1)*10)
      IF(IQUANT(I).GT.0) THEN
         OUT(1+J)=NTGRAL(I)
      ELSE
         OUT(1+J)=XSUM(I)
      ENDIF
      OUT(2+J)=NUM(I)
      OUT(3+J)=MEAN(I)
      OUT(4+J)=STDEV(I)
      OUT(5+J)=VAR(I)
      OUT(6+J)=SSQ(I)
      OUT(7+J)=VMIN(I)
      OUT(8+J)=TMIN(I)
      OUT(9+J)=VMAX(I)
      OUT(10+J)=TMAX(I)

      IF(((TIME.GE.(NEWVAL(I)+DT/2.)).AND.(TIME.LE.(NEWVAL(I)
     1   +3.*DT/2.)).OR.(TIME.GE.(TIMEF-DT/2.)))) THEN

C       SET THE NEW RESET TIME
         IF(MONTH3(I)) THEN
            NEWVAL(I)=MONTH(KEEP(I)+1)
         ELSE
            NEWVAL(I)=NEWVAL(I)+RESET(I)
         ENDIF
      ENDIF

C    UPDATE THE MONTH COUNTER
      IF(TIME.GE.(MONTH(KEEP(I))+DT/2.)) KEEP(I)=KEEP(I)+1

C    RESET THE S VARIABLES
      S(JJ+I+20)=XREPEAT(I)
      S(JJ+I+30)=RESET(I)
      S(JJ+I+90)=NEXT(I)
      S(JJ+I+100)=LAST(I)
      S(JJ+I+110)=REAL(NUM(I))
      S(JJ+I+120)=XSUM(I)
      S(JJ+I+130)=SUMSQ(I)
      S(JJ+I+140)=NTGRAL(I)
      S(JJ+I+150)=VMAX(I)
      S(JJ+I+160)=TMAX(I)
      S(JJ+I+170)=VMIN(I)
      S(JJ+I+180)=TMIN(I)
      S(JJ+I+190)=MEAN(I)
      S(JJ+I+200)=STDEV(I)
      S(JJ+I+210)=VAR(I)
      S(JJ+I+220)=SSQ(I)
      S(JJ+I+230)=REAL(KEEP(I))
      S(JJ+I+240)=NEWVAL(I)

 50   CONTINUE
      RETURN 1
      END

